You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@struts.apache.org by mr...@apache.org on 2006/03/29 02:52:51 UTC

svn commit: r389643 [3/4] - in /incubator/webwork2: ./ src/etc/ src/java/ src/java/org/apache/struts/action2/ src/java/org/apache/struts/action2/components/ src/java/org/apache/struts/action2/components/ajax/ src/java/org/apache/struts/action2/componen...

Copied: incubator/webwork2/src/java/org/apache/struts/action2/util/StrutsUtil.java (from r389620, incubator/webwork2/src/java/org/apache/struts/action2/util/WebWorkUtil.java)
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/util/StrutsUtil.java?p2=incubator/webwork2/src/java/org/apache/struts/action2/util/StrutsUtil.java&p1=incubator/webwork2/src/java/org/apache/struts/action2/util/WebWorkUtil.java&r1=389620&r2=389643&rev=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/util/WebWorkUtil.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/util/StrutsUtil.java Tue Mar 28 16:52:39 2006
@@ -32,9 +32,9 @@
  * @author Cameron Braid
  * @version $Revision: 1.19 $
  */
-public class WebWorkUtil {
+public class StrutsUtil {
 
-    protected static final Log log = LogFactory.getLog(WebWorkUtil.class);
+    protected static final Log log = LogFactory.getLog(StrutsUtil.class);
 
 
     protected HttpServletRequest request;
@@ -44,7 +44,7 @@
     protected OgnlValueStack stack;
 
 
-    public WebWorkUtil(OgnlValueStack stack, HttpServletRequest request, HttpServletResponse response) {
+    public StrutsUtil(OgnlValueStack stack, HttpServletRequest request, HttpServletResponse response) {
         this.stack = stack;
         this.request = request;
         this.response = response;
@@ -56,7 +56,7 @@
         Class c = (Class) classes.get(name);
 
         if (c == null) {
-            c = ClassLoaderUtils.loadClass(name, WebWorkUtil.class);
+            c = ClassLoaderUtils.loadClass(name, StrutsUtil.class);
             classes.put(name, c);
         }
 

Modified: incubator/webwork2/src/java/org/apache/struts/action2/util/TokenHelper.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/util/TokenHelper.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/util/TokenHelper.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/util/TokenHelper.java Tue Mar 28 16:52:39 2006
@@ -25,12 +25,12 @@
     /**
      * The default name to map the token value
      */
-    public static final String DEFAULT_TOKEN_NAME = "webwork.token";
+    public static final String DEFAULT_TOKEN_NAME = "struts.token";
 
     /**
      * The name of the field which will hold the token name
      */
-    public static final String TOKEN_NAME_FIELD = "webwork.token.name";
+    public static final String TOKEN_NAME_FIELD = "struts.token.name";
     private static final Log LOG = LogFactory.getLog(TokenHelper.class);
 
 
@@ -152,7 +152,7 @@
         String sessionToken = (String) session.get(tokenName);
 
         if (!token.equals(sessionToken)) {
-            LOG.warn(LocalizedTextUtil.findText(TokenHelper.class, "webwork.internal.invalid.token", ActionContext.getContext().getLocale(), "Form token {0} does not match the session token {1}.", new Object[]{
+            LOG.warn(LocalizedTextUtil.findText(TokenHelper.class, "struts.internal.invalid.token", ActionContext.getContext().getLocale(), "Form token {0} does not match the session token {1}.", new Object[]{
                     token, sessionToken
             }));
 

Copied: incubator/webwork2/src/java/org/apache/struts/action2/util/VelocityStrutsUtil.java (from r389620, incubator/webwork2/src/java/org/apache/struts/action2/util/VelocityWebWorkUtil.java)
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/util/VelocityStrutsUtil.java?p2=incubator/webwork2/src/java/org/apache/struts/action2/util/VelocityStrutsUtil.java&p1=incubator/webwork2/src/java/org/apache/struts/action2/util/VelocityWebWorkUtil.java&r1=389620&r2=389643&rev=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/FreemarkerManager.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/FreemarkerManager.java Tue Mar 28 16:52:39 2006
@@ -7,9 +7,9 @@
 import com.opensymphony.util.FileManager;
 import org.apache.struts.action2.config.Configuration;
 import org.apache.struts.action2.views.JspSupportServlet;
-import org.apache.struts.action2.views.freemarker.tags.WebWorkModels;
+import org.apache.struts.action2.views.freemarker.tags.StrutsModels;
 import org.apache.struts.action2.views.util.ContextUtil;
-import org.apache.struts.action2.WebWorkConstants;
+import org.apache.struts.action2.StrutsConstants;
 import com.opensymphony.xwork.ObjectFactory;
 import com.opensymphony.xwork.util.OgnlValueStack;
 import freemarker.cache.FileTemplateLoader;
@@ -66,7 +66,7 @@
     /**
      * To allow for custom configuration of freemarker, sublcass this class "ConfigManager" and
      * set the webwork configuration property
-     * <b>webwork.freemarker.configmanager.classname</b> to the fully qualified classname.
+     * <b>struts.freemarker.configmanager.classname</b> to the fully qualified classname.
      * <p/>
      * This allows you to override the protected methods in the ConfigMangaer
      * to programatically create your own Configuration instance
@@ -75,8 +75,8 @@
         if (instance == null) {
             String classname = FreemarkerManager.class.getName();
 
-            if (Configuration.isSet(WebWorkConstants.WEBWORK_FREEMARKER_MANAGER_CLASSNAME)) {
-                classname = Configuration.getString(WebWorkConstants.WEBWORK_FREEMARKER_MANAGER_CLASSNAME).trim();
+            if (Configuration.isSet(StrutsConstants.STRUTS_FREEMARKER_MANAGER_CLASSNAME)) {
+                classname = Configuration.getString(StrutsConstants.STRUTS_FREEMARKER_MANAGER_CLASSNAME).trim();
             }
 
             try {
@@ -179,7 +179,7 @@
     }
 
     protected BeansWrapper getObjectWrapper() {
-        return new WebWorkBeanWrapper();
+        return new StrutsBeanWrapper();
     }
 
     /**
@@ -215,11 +215,11 @@
                 new MultiTemplateLoader(new TemplateLoader[]{
                         templatePathLoader,
                         new WebappTemplateLoader(servletContext),
-                        new WebWorkClassTemplateLoader()
+                        new StrutsClassTemplateLoader()
                 })
                 : new MultiTemplateLoader(new TemplateLoader[]{
                 new WebappTemplateLoader(servletContext),
-                new WebWorkClassTemplateLoader()
+                new StrutsClassTemplateLoader()
         });
     }
 
@@ -245,8 +245,8 @@
 
         configuration.setObjectWrapper(getObjectWrapper());
         
-        if (Configuration.isSet(WebWorkConstants.WEBWORK_I18N_ENCODING)) {
-        	configuration.setDefaultEncoding(Configuration.getString(WebWorkConstants.WEBWORK_I18N_ENCODING));
+        if (Configuration.isSet(StrutsConstants.STRUTS_I18N_ENCODING)) {
+        	configuration.setDefaultEncoding(Configuration.getString(StrutsConstants.STRUTS_I18N_ENCODING));
         }
 
         loadSettings(servletContext, configuration);
@@ -278,7 +278,7 @@
     public SimpleHash buildTemplateModel(OgnlValueStack stack, Object action, ServletContext servletContext, HttpServletRequest request, HttpServletResponse response, ObjectWrapper wrapper) {
         ScopesHashModel model = buildScopesHashModel(servletContext, request, response, wrapper, stack);
         populateContext(model, stack, action, request, response);
-        model.put("ww", new WebWorkModels(stack, request, response));
+        model.put("ww", new StrutsModels(stack, request, response));
         return model;
     }
 }

Modified: incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/FreemarkerResult.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/FreemarkerResult.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/FreemarkerResult.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/FreemarkerResult.java Tue Mar 28 16:52:39 2006
@@ -8,7 +8,7 @@
 package org.apache.struts.action2.views.freemarker;
 
 import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.dispatcher.WebWorkResultSupport;
+import org.apache.struts.action2.dispatcher.StrutsResultSupport;
 import org.apache.struts.action2.views.util.ResourceUtil;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.ActionInvocation;
@@ -71,7 +71,7 @@
  * <!-- END SNIPPET: example --></pre>
  * @author CameronBraid
  */
-public class FreemarkerResult extends WebWorkResultSupport {
+public class FreemarkerResult extends StrutsResultSupport {
 
     protected ActionInvocation invocation;
     protected Configuration configuration;
@@ -185,7 +185,7 @@
      * <li>ognl - the instance of the OgnlTool
      * <li>action - the action itself
      * <li>exception - optional : the JSP or Servlet exception as per the servlet spec (for JSP Exception pages)
-     * <li>webwork - instance of the WebWorkUtil class
+     * <li>webwork - instance of the StrutsUtil class
      * </ul>
      */
     protected TemplateModel createModel() throws TemplateModelException {

Modified: incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/FreemarkerServlet.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/FreemarkerServlet.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/FreemarkerServlet.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/FreemarkerServlet.java Tue Mar 28 16:52:39 2006
@@ -41,12 +41,12 @@
 
 
     final public void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
-        request.setAttribute("webwork.freemarker.servlet", this);
+        request.setAttribute("struts.freemarker.servlet", this);
         process(request, response);
     }
 
     final public void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
-        request.setAttribute("webwork.freemarker.servlet", this);
+        request.setAttribute("struts.freemarker.servlet", this);
         process(request, response);
     }
 

Modified: incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/PortletFreemarkerResult.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/PortletFreemarkerResult.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/PortletFreemarkerResult.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/PortletFreemarkerResult.java Tue Mar 28 16:52:39 2006
@@ -16,7 +16,7 @@
 import javax.servlet.http.HttpServletResponse;
 
 import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.dispatcher.WebWorkResultSupport;
+import org.apache.struts.action2.dispatcher.StrutsResultSupport;
 import org.apache.struts.action2.portlet.PortletActionConstants;
 import org.apache.struts.action2.portlet.context.PortletActionContext;
 import org.apache.struts.action2.views.util.ResourceUtil;
@@ -35,7 +35,7 @@
 /**
  * @author CameronBraid
  */
-public class PortletFreemarkerResult extends WebWorkResultSupport {
+public class PortletFreemarkerResult extends StrutsResultSupport {
 
     protected ActionInvocation invocation;
 
@@ -192,7 +192,7 @@
      * <li>action - the action itself
      * <li>exception - optional : the JSP or Servlet exception as per the
      * servlet spec (for JSP Exception pages)
-     * <li>webwork - instance of the WebWorkUtil class
+     * <li>webwork - instance of the StrutsUtil class
      * </ul>
      */
     protected TemplateModel createModel() throws TemplateModelException {

Copied: incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/StrutsBeanWrapper.java (from r389620, incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/WebWorkBeanWrapper.java)
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/StrutsBeanWrapper.java?p2=incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/StrutsBeanWrapper.java&p1=incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/WebWorkBeanWrapper.java&r1=389620&r2=389643&rev=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/WebWorkClassTemplateLoader.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/StrutsClassTemplateLoader.java Tue Mar 28 16:52:39 2006
@@ -10,7 +10,7 @@
  * Date: Aug 10, 2005
  * Time: 11:25:05 PM
  */
-public class WebWorkClassTemplateLoader extends URLTemplateLoader {
+public class StrutsClassTemplateLoader extends URLTemplateLoader {
     protected URL getURL(String name) {
         return ClassLoaderUtil.getResource(name, getClass());
     }

Copied: incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/tags/StrutsModels.java (from r389620, incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/tags/WebWorkModels.java)
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/tags/StrutsModels.java?p2=incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/tags/StrutsModels.java&p1=incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/tags/WebWorkModels.java&r1=389620&r2=389643&rev=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/tags/WebWorkModels.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/tags/StrutsModels.java Tue Mar 28 16:52:39 2006
@@ -10,7 +10,7 @@
  *
  * @author plightbo
  */
-public class WebWorkModels {
+public class StrutsModels {
     protected OgnlValueStack stack;
     protected HttpServletRequest req;
     protected HttpServletResponse res;
@@ -61,7 +61,7 @@
     protected RichTextEditorModel richtexteditorModel;
     
 
-    public WebWorkModels(OgnlValueStack stack, HttpServletRequest req, HttpServletResponse res) {
+    public StrutsModels(OgnlValueStack stack, HttpServletRequest req, HttpServletResponse res) {
         this.stack = stack;
         this.req = req;
         this.res = res;

Modified: incubator/webwork2/src/java/org/apache/struts/action2/views/jasperreports/JasperReportsResult.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/jasperreports/JasperReportsResult.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/ComponentTagSupport.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/ComponentTagSupport.java Tue Mar 28 16:52:39 2006
@@ -12,7 +12,7 @@
  * Date: Sep 1, 2005
  * Time: 8:44:53 PM
  */
-public abstract class ComponentTagSupport extends WebWorkBodyTagSupport {
+public abstract class ComponentTagSupport extends StrutsBodyTagSupport {
     protected Component component;
 
     public abstract Component getBean(OgnlValueStack stack, HttpServletRequest req, HttpServletResponse res);

Copied: incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/StrutsBodyTagSupport.java (from r389620, incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/WebWorkBodyTagSupport.java)
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/StrutsBodyTagSupport.java?p2=incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/StrutsBodyTagSupport.java&p1=incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/WebWorkBodyTagSupport.java&r1=389620&r2=389643&rev=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/TagUtils.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/TagUtils.java Tue Mar 28 16:52:39 2006
@@ -33,7 +33,7 @@
 
     public static OgnlValueStack getStack(PageContext pageContext) {
         HttpServletRequest req = (HttpServletRequest) pageContext.getRequest();
-        OgnlValueStack stack = (OgnlValueStack) req.getAttribute(ServletActionContext.WEBWORK_VALUESTACK_KEY);
+        OgnlValueStack stack = (OgnlValueStack) req.getAttribute(ServletActionContext.STRUTS_VALUESTACK_KEY);
 
         if (stack == null) {
             stack = new OgnlValueStack();
@@ -50,7 +50,7 @@
                     pageContext.getServletContext());
             extraContext.put(ServletActionContext.PAGE_CONTEXT, pageContext);
             stack.getContext().putAll(extraContext);
-            req.setAttribute(ServletActionContext.WEBWORK_VALUESTACK_KEY, stack);
+            req.setAttribute(ServletActionContext.STRUTS_VALUESTACK_KEY, stack);
 
             // also tie this stack/context to the ThreadLocal
             ActionContext.setContext(new ActionContext(stack.getContext()));

Modified: incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/iterator/IteratorGeneratorTag.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/iterator/IteratorGeneratorTag.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/iterator/IteratorGeneratorTag.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/iterator/IteratorGeneratorTag.java Tue Mar 28 16:52:39 2006
@@ -6,7 +6,7 @@
 
 import org.apache.struts.action2.util.IteratorGenerator;
 import org.apache.struts.action2.util.IteratorGenerator.Converter;
-import org.apache.struts.action2.views.jsp.WebWorkBodyTagSupport;
+import org.apache.struts.action2.views.jsp.StrutsBodyTagSupport;
 
 import javax.servlet.jsp.JspException;
 
@@ -113,7 +113,7 @@
  * @ww.tag name="generator" tld-body-content="JSP"
  * description="Generate an iterator for a iterable source."
  */
-public class IteratorGeneratorTag extends WebWorkBodyTagSupport {
+public class IteratorGeneratorTag extends StrutsBodyTagSupport {
 
 	private static final long serialVersionUID = 2968037295463973936L;
 

Modified: incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/iterator/SortIteratorTag.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/iterator/SortIteratorTag.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/iterator/SortIteratorTag.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/iterator/SortIteratorTag.java Tue Mar 28 16:52:39 2006
@@ -6,7 +6,7 @@
 
 import org.apache.struts.action2.util.MakeIterator;
 import org.apache.struts.action2.util.SortIteratorFilter;
-import org.apache.struts.action2.views.jsp.WebWorkBodyTagSupport;
+import org.apache.struts.action2.views.jsp.StrutsBodyTagSupport;
 
 import javax.servlet.jsp.JspException;
 
@@ -70,7 +70,7 @@
  * @ww.tag name="sort" tld-body-content="JSP"
  * description="Sort a List using a Comparator both passed in as the tag attribute."
  */
-public class SortIteratorTag extends WebWorkBodyTagSupport {
+public class SortIteratorTag extends StrutsBodyTagSupport {
 
 	private static final long serialVersionUID = -7835719609764092235L;
 

Modified: incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/iterator/SubsetIteratorTag.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/iterator/SubsetIteratorTag.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/iterator/SubsetIteratorTag.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/iterator/SubsetIteratorTag.java Tue Mar 28 16:52:39 2006
@@ -6,7 +6,7 @@
 
 import org.apache.struts.action2.util.SubsetIteratorFilter;
 import org.apache.struts.action2.util.SubsetIteratorFilter.Decider;
-import org.apache.struts.action2.views.jsp.WebWorkBodyTagSupport;
+import org.apache.struts.action2.views.jsp.StrutsBodyTagSupport;
 
 import javax.servlet.jsp.JspException;
 
@@ -132,7 +132,7 @@
  * @ww.tag name="subset" tld-body-content="JSP"
  * description="Takes an iterator and outputs a subset of it"
  */
-public class SubsetIteratorTag extends WebWorkBodyTagSupport {
+public class SubsetIteratorTag extends StrutsBodyTagSupport {
 
 	private static final long serialVersionUID = -6252696081713080102L;
 

Modified: incubator/webwork2/src/java/org/apache/struts/action2/views/util/ContextUtil.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/util/ContextUtil.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/util/ContextUtil.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/util/ContextUtil.java Tue Mar 28 16:52:39 2006
@@ -9,8 +9,8 @@
 import com.opensymphony.xwork.ActionContext;
 import org.apache.struts.action2.views.jsp.ui.OgnlTool;
 import org.apache.struts.action2.config.Configuration;
-import org.apache.struts.action2.util.WebWorkUtil;
-import org.apache.struts.action2.WebWorkConstants;
+import org.apache.struts.action2.util.StrutsUtil;
+import org.apache.struts.action2.StrutsConstants;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -33,7 +33,7 @@
     public static final String BASE = "base";
     public static final String STACK = "stack";
     public static final String OGNL = "ognl";
-    public static final String WEBWORK = "webwork";
+    public static final String STRUTS = "webwork";
     public static final String ACTION = "action";
 
     public static Map getStandardContext(OgnlValueStack stack, HttpServletRequest req, HttpServletResponse res) {
@@ -46,7 +46,7 @@
         map.put(BASE, req.getContextPath());
         map.put(STACK, stack);
         map.put(OGNL, OgnlTool.getInstance());
-        map.put(WEBWORK, new WebWorkUtil(stack, req, res));
+        map.put(STRUTS, new StrutsUtil(stack, req, res));
 
         ActionInvocation invocation = (ActionInvocation) stack.getContext().get(ActionContext.ACTION_INVOCATION);
         if (invocation != null) {
@@ -61,10 +61,10 @@
      * @return boolean
      */
     public static boolean isUseAltSyntax(Map context) {
-        // We didn't make altSyntax static cause, if so, webwork.configuration.xml.reload will not work
+        // We didn't make altSyntax static cause, if so, struts.configuration.xml.reload will not work
         // plus the Configuration implementation should cache the properties, which WW's
         // configuration implementation does
-        boolean altSyntax = "true".equals(Configuration.getString(WebWorkConstants.WEBWORK_TAG_ALTSYNTAX));
+        boolean altSyntax = "true".equals(Configuration.getString(StrutsConstants.STRUTS_TAG_ALTSYNTAX));
         return altSyntax ||(
                 (context.containsKey("useAltSyntax") &&
                         context.get("useAltSyntax") != null &&

Modified: incubator/webwork2/src/java/org/apache/struts/action2/views/util/UrlHelper.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/util/UrlHelper.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/util/UrlHelper.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/util/UrlHelper.java Tue Mar 28 16:52:39 2006
@@ -1,7 +1,7 @@
 package org.apache.struts.action2.views.util;
 
 import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.WebWorkConstants;
+import org.apache.struts.action2.StrutsConstants;
 import org.apache.struts.action2.config.Configuration;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.util.OgnlValueStack;
@@ -55,14 +55,14 @@
         int httpPort = DEFAULT_HTTP_PORT;
 
         try {
-            httpPort = Integer.parseInt((String) Configuration.get(WebWorkConstants.WEBWORK_URL_HTTP_PORT));
+            httpPort = Integer.parseInt((String) Configuration.get(StrutsConstants.STRUTS_URL_HTTP_PORT));
         } catch (Exception ex) {
         }
 
         int httpsPort = DEFAULT_HTTPS_PORT;
 
         try {
-            httpsPort = Integer.parseInt((String) Configuration.get(WebWorkConstants.WEBWORK_URL_HTTPS_PORT));
+            httpsPort = Integer.parseInt((String) Configuration.get(StrutsConstants.STRUTS_URL_HTTPS_PORT));
         } catch (Exception ex) {
         }
 
@@ -112,7 +112,7 @@
             link.append(action);
         } else {
             // Go to "same page"
-            String requestURI = (String) request.getAttribute("webwork.request_uri");
+            String requestURI = (String) request.getAttribute("struts.request_uri");
 
             if (requestURI == null) {
                 requestURI = request.getRequestURI();
@@ -205,8 +205,8 @@
         String output = TextParseUtil.translateVariables(input, valueStack);
 
         final String encoding;
-        if (Configuration.isSet(WebWorkConstants.WEBWORK_I18N_ENCODING)) {
-            encoding = Configuration.getString(WebWorkConstants.WEBWORK_I18N_ENCODING);
+        if (Configuration.isSet(StrutsConstants.STRUTS_I18N_ENCODING)) {
+            encoding = Configuration.getString(StrutsConstants.STRUTS_I18N_ENCODING);
         } else {
             encoding = "UTF-8";
         }

Copied: incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/StrutsResourceLoader.java (from r389620, incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/WebWorkResourceLoader.java)
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/StrutsResourceLoader.java?p2=incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/StrutsResourceLoader.java&p1=incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/WebWorkResourceLoader.java&r1=389620&r2=389643&rev=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/WebWorkResourceLoader.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/StrutsResourceLoader.java Tue Mar 28 16:52:39 2006
@@ -17,7 +17,7 @@
  * @author $Author: plightbo $
  * @version $Revision: 1.4 $
  */
-public class WebWorkResourceLoader extends ClasspathResourceLoader {
+public class StrutsResourceLoader extends ClasspathResourceLoader {
 
     public synchronized InputStream getResourceStream(String name) throws ResourceNotFoundException {
         if ((name == null) || (name.length() == 0)) {
@@ -29,7 +29,7 @@
         }
 
         try {
-            return ClassLoaderUtils.getResourceAsStream(name, WebWorkResourceLoader.class);
+            return ClassLoaderUtils.getResourceAsStream(name, StrutsResourceLoader.class);
         } catch (Exception e) {
             throw new ResourceNotFoundException(e.getMessage());
         }

Copied: incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/StrutsVelocityContext.java (from r389620, incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/WebWorkVelocityContext.java)
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/StrutsVelocityContext.java?p2=incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/StrutsVelocityContext.java&p1=incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/WebWorkVelocityContext.java&r1=389620&r2=389643&rev=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/WebWorkVelocityContext.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/StrutsVelocityContext.java Tue Mar 28 16:52:39 2006
@@ -12,17 +12,17 @@
  * @author $Author: plightbo $
  * @version $Revision: 1.11 $
  */
-public class WebWorkVelocityContext extends VelocityContext {
+public class StrutsVelocityContext extends VelocityContext {
 
     OgnlValueStack stack;
     VelocityContext[] chainedContexts;
 
 
-    public WebWorkVelocityContext(OgnlValueStack stack) {
+    public StrutsVelocityContext(OgnlValueStack stack) {
         this(null, stack);
     }
 
-    public WebWorkVelocityContext(VelocityContext[] chainedContexts, OgnlValueStack stack) {
+    public StrutsVelocityContext(VelocityContext[] chainedContexts, OgnlValueStack stack) {
         this.chainedContexts = chainedContexts;
         this.stack = stack;
     }

Copied: incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/StrutsVelocityServlet.java (from r389620, incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/WebWorkVelocityServlet.java)
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/StrutsVelocityServlet.java?p2=incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/StrutsVelocityServlet.java&p1=incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/WebWorkVelocityServlet.java&r1=389620&r2=389643&rev=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/WebWorkVelocityServlet.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/StrutsVelocityServlet.java Tue Mar 28 16:52:39 2006
@@ -6,7 +6,7 @@
 
 import org.apache.struts.action2.RequestUtils;
 import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.WebWorkConstants;
+import org.apache.struts.action2.StrutsConstants;
 import org.apache.struts.action2.config.Configuration;
 import org.apache.struts.action2.views.util.ContextUtil;
 import com.opensymphony.xwork.ActionContext;
@@ -36,10 +36,10 @@
  * @version $Revision: 1.20 $
  * @deprecated please use {@link org.apache.struts.action2.dispatcher.VelocityResult} instead of direct access
  */
-public class WebWorkVelocityServlet extends VelocityServlet {
+public class StrutsVelocityServlet extends VelocityServlet {
     private VelocityManager velocityManager;
 
-    public WebWorkVelocityServlet() {
+    public StrutsVelocityServlet() {
         velocityManager = VelocityManager.getInstance();
     }
 
@@ -69,7 +69,7 @@
      * <ul>
      * <li>invokes VelocityServlet.loadConfiguration to create a properties object</li>
      * <li>alters the RESOURCE_LOADER to include a class loader</li>
-     * <li>configures the class loader using the WebWorkResourceLoader</li>
+     * <li>configures the class loader using the StrutsResourceLoader</li>
      * </ul>
      *
      * @param servletConfig
@@ -111,9 +111,9 @@
     }
 
     private String getEncoding() {
-        // todo look into converting this to using XWork/WebWork2 encoding rules
+        // todo look into converting this to using XWork/Struts encoding rules
         try {
-            return Configuration.getString(WebWorkConstants.WEBWORK_I18N_ENCODING);
+            return Configuration.getString(StrutsConstants.STRUTS_I18N_ENCODING);
         } catch (IllegalArgumentException e) {
             return RuntimeSingleton.getString(RuntimeSingleton.OUTPUT_ENCODING, DEFAULT_OUTPUT_ENCODING);
         }

Modified: incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/VelocityManager.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/VelocityManager.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/xslt/BeanAdapter.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/xslt/BeanAdapter.java Tue Mar 28 16:52:39 2006
@@ -68,7 +68,7 @@
                 Object propertyValue = null;
 
                 /** 999 white magic hack start 999 **
-                 * some property accessors will throw exceptions, e.g. getLocale() in webwork.ActionSupport *grrr*
+                 * some property accessors will throw exceptions, e.g. getLocale() in struts.ActionSupport *grrr*
                  * IMHO property accessors should not have those side effects - meier@meisterbohne.de
                  */
                 try {

Modified: incubator/webwork2/src/java/org/apache/struts/action2/views/xslt/XSLTResult.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/xslt/XSLTResult.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/xslt/XSLTResult.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/xslt/XSLTResult.java Tue Mar 28 16:52:39 2006
@@ -5,7 +5,7 @@
 package org.apache.struts.action2.views.xslt;
 
 import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.WebWorkConstants;
+import org.apache.struts.action2.StrutsConstants;
 import org.apache.struts.action2.config.Configuration;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.ActionInvocation;
@@ -148,11 +148,11 @@
  * </ul>
  *
  * <p>
- * <code>webwork.properties</code> related configuration:
+ * <code>struts.properties</code> related configuration:
  * </p>
  * <ul>
  *
- * <li><b>webwork.xslt.nocache</b> - Defaults to false. If set to true, disables
+ * <li><b>struts.xslt.nocache</b> - Defaults to false. If set to true, disables
  * stylesheet caching. Good for development, bad for production.</li>
  *
  * </ul>
@@ -185,7 +185,7 @@
 
     public XSLTResult() {
         templatesCache = new HashMap();
-        noCache = Configuration.getString(WebWorkConstants.WEBWORK_XSLT_NOCACHE).trim().equalsIgnoreCase("true");
+        noCache = Configuration.getString(StrutsConstants.STRUTS_XSLT_NOCACHE).trim().equalsIgnoreCase("true");
     }
 
     public void setLocation(String location) {

Copied: incubator/webwork2/src/java/struts-default.xml (from r389620, incubator/webwork2/src/java/webwork-default.xml)
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/struts-default.xml?p2=incubator/webwork2/src/java/struts-default.xml&p1=incubator/webwork2/src/java/webwork-default.xml&r1=389620&r2=389643&rev=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/webwork-default.xml (original)
+++ incubator/webwork2/src/java/struts-default.xml Tue Mar 28 16:52:39 2006
@@ -1,6 +1,6 @@
 <!DOCTYPE xwork PUBLIC "-//OpenSymphony Group//XWork 1.1.1//EN" "http://www.opensymphony.com/xwork/xwork-1.1.1.dtd">
 <xwork>
-    <package name="webwork-default">
+    <package name="struts-default">
         <result-types>
             <result-type name="chain" class="com.opensymphony.xwork.ActionChainResult"/>
             <result-type name="dispatcher" class="org.apache.struts.action2.dispatcher.ServletDispatcherResult" default="true"/>
@@ -28,7 +28,7 @@
             <interceptor name="autowiring" class="com.opensymphony.xwork.spring.interceptor.ActionAutowiringInterceptor"/>
             <interceptor name="chain" class="com.opensymphony.xwork.interceptor.ChainingInterceptor"/>
             <interceptor name="component" class="com.opensymphony.xwork.interceptor.component.ComponentInterceptor"/>
-            <interceptor name="conversionError" class="org.apache.struts.action2.interceptor.WebWorkConversionErrorInterceptor"/>
+            <interceptor name="conversionError" class="org.apache.struts.action2.interceptor.StrutsConversionErrorInterceptor"/>
             <interceptor name="createSession" class="org.apache.struts.action2.interceptor.CreateSessionInterceptor" />
             <interceptor name="external-ref" class="com.opensymphony.xwork.interceptor.ExternalReferencesInterceptor"/>
             <interceptor name="execAndWait" class="org.apache.struts.action2.interceptor.ExecuteAndWaitInterceptor"/>
@@ -72,8 +72,8 @@
                 <interceptor-ref name="basicStack"/>
             </interceptor-stack>
 
-            <!-- Sample WebWork Inversion of Control stack
-                 Note: WebWork's IoC is deprecated - please
+            <!-- Sample Struts Inversion of Control stack
+                 Note: Struts's IoC is deprecated - please
                  look at alternatives such as Spring -->
             <interceptor-stack name="componentStack">
                 <interceptor-ref name="component"/>
@@ -179,7 +179,7 @@
 
         <default-interceptor-ref name="defaultStack"/>
     </package>
-    <package name="webwork-portlet-default" extends="webwork-default">
+    <package name="struts-portlet-default" extends="struts-default">
 
 	   <result-types>
 			<result-type name="dispatcher" class="org.apache.struts.action2.portlet.result.PortletResult" default="true"/>

Modified: incubator/webwork2/src/test/org/apache/struts/action2/ServletActionContextTest.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/ServletActionContextTest.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/ServletActionContextTest.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/ServletActionContextTest.java Tue Mar 28 16:52:39 2006
@@ -22,7 +22,7 @@
  *
  * @author <a href="mailto:nightfal@etherlands.net">Erik Beeson</a>
  */
-public class ServletActionContextTest extends TestCase implements WebWorkStatics {
+public class ServletActionContextTest extends TestCase implements StrutsStatics {
 
     ActionContext actionContext;
     ServletActionContext servletActionContext;

Modified: incubator/webwork2/src/test/org/apache/struts/action2/components/PropertyTest.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/components/PropertyTest.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/components/PropertyTest.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/components/PropertyTest.java Tue Mar 28 16:52:39 2006
@@ -1,7 +1,7 @@
 package org.apache.struts.action2.components;
 
 import org.apache.struts.action2.components.Property;
-import org.apache.struts.action2.util.WebWorkTypeConverter;
+import org.apache.struts.action2.util.StrutsTypeConverter;
 import com.opensymphony.xwork.util.OgnlValueStack;
 import com.opensymphony.xwork.util.XWorkConverter;
 import junit.framework.TestCase;
@@ -102,7 +102,7 @@
         }
     }
  
-    private final class FooBarConverter extends WebWorkTypeConverter {
+    private final class FooBarConverter extends StrutsTypeConverter {
         public Object convertFromString(Map context, String[] values, Class toClass) {
             return null;
         }

Modified: incubator/webwork2/src/test/org/apache/struts/action2/config/ConfigurationTest.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/config/ConfigurationTest.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/config/ConfigurationTest.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/config/ConfigurationTest.java Tue Mar 28 16:52:39 2006
@@ -4,8 +4,8 @@
  */
 package org.apache.struts.action2.config;
 
-import org.apache.struts.action2.WebWorkTestCase;
-import org.apache.struts.action2.WebWorkConstants;
+import org.apache.struts.action2.StrutsTestCase;
+import org.apache.struts.action2.StrutsConstants;
 import com.opensymphony.xwork.util.LocalizedTextUtil;
 
 import java.util.Iterator;
@@ -17,13 +17,13 @@
  *
  * @author Jason Carreira
  */
-public class ConfigurationTest extends WebWorkTestCase {
+public class ConfigurationTest extends StrutsTestCase {
 
     public void testConfiguration() {
-        assertEquals("12345", Configuration.getString(WebWorkConstants.WEBWORK_MULTIPART_MAXSIZE));
-        assertEquals("\temp", Configuration.getString(WebWorkConstants.WEBWORK_MULTIPART_SAVEDIR));
+        assertEquals("12345", Configuration.getString(StrutsConstants.STRUTS_MULTIPART_MAXSIZE));
+        assertEquals("\temp", Configuration.getString(StrutsConstants.STRUTS_MULTIPART_SAVEDIR));
 
-        assertEquals("test,org/apache/struts/action2/othertest", Configuration.getString( WebWorkConstants.WEBWORK_CUSTOM_PROPERTIES));
+        assertEquals("test,org/apache/struts/action2/othertest", Configuration.getString( StrutsConstants.STRUTS_CUSTOM_PROPERTIES));
         assertEquals("testvalue", Configuration.getString("testkey"));
         assertEquals("othertestvalue", Configuration.getString("othertestkey"));
 
@@ -35,7 +35,7 @@
     }
 
     public void testDefaultResourceBundlesLoaded() {
-        assertEquals("testmessages,testmessages2", Configuration.getString(WebWorkConstants.WEBWORK_CUSTOM_I18N_RESOURCES));
+        assertEquals("testmessages,testmessages2", Configuration.getString(StrutsConstants.STRUTS_CUSTOM_I18N_RESOURCES));
         assertEquals("This is a test message", LocalizedTextUtil.findDefaultText("default.testmessage", Locale.getDefault()));
         assertEquals("This is another test message", LocalizedTextUtil.findDefaultText("default.testmessage2", Locale.getDefault()));
     }
@@ -44,12 +44,12 @@
         Locale.setDefault(Locale.US); // force to US locale as we also have _de and _da properties
         
         LocalizedTextUtil.clearDefaultResourceBundles();
-        LocalizedTextUtil.addDefaultResourceBundle("org/apache/struts/action2/webwork-messages");
-        assertEquals("The form has already been processed or no token was supplied, please try again.", LocalizedTextUtil.findDefaultText("webwork.messages.invalid.token", Locale.getDefault()));
+        LocalizedTextUtil.addDefaultResourceBundle("org/apache/struts/action2/struts-messages");
+        assertEquals("The form has already been processed or no token was supplied, please try again.", LocalizedTextUtil.findDefaultText("struts.messages.invalid.token", Locale.getDefault()));
         Configuration.reset();
 
-        assertEquals("testmessages,testmessages2", Configuration.getString(WebWorkConstants.WEBWORK_CUSTOM_I18N_RESOURCES));
-        assertEquals("Replaced message for token tag", LocalizedTextUtil.findDefaultText("webwork.messages.invalid.token", Locale.getDefault()));
+        assertEquals("testmessages,testmessages2", Configuration.getString(StrutsConstants.STRUTS_CUSTOM_I18N_RESOURCES));
+        assertEquals("Replaced message for token tag", LocalizedTextUtil.findDefaultText("struts.messages.invalid.token", Locale.getDefault()));
     }
 
     public void testSetConfiguration() {

Modified: incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/AbstractServletDispatcherTestCase.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/AbstractServletDispatcherTestCase.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/AbstractServletDispatcherTestCase.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/AbstractServletDispatcherTestCase.java Tue Mar 28 16:52:39 2006
@@ -14,9 +14,9 @@
 import com.mockobjects.servlet.MockHttpSession;
 import com.mockobjects.servlet.MockServletConfig;
 import com.mockobjects.servlet.MockServletOutputStream;
-import org.apache.struts.action2.WebWorkTestCase;
-import org.apache.struts.action2.views.jsp.WebWorkMockHttpServletRequest;
-import org.apache.struts.action2.views.jsp.WebWorkMockHttpServletResponse;
+import org.apache.struts.action2.StrutsTestCase;
+import org.apache.struts.action2.views.jsp.StrutsMockHttpServletRequest;
+import org.apache.struts.action2.views.jsp.StrutsMockHttpServletResponse;
 import com.opensymphony.xwork.config.ConfigurationManager;
 import com.opensymphony.xwork.config.providers.XmlConfigurationProvider;
 
@@ -32,7 +32,7 @@
 /**
  * @author CameronBraid
  */
-public abstract class AbstractServletDispatcherTestCase extends WebWorkTestCase {
+public abstract class AbstractServletDispatcherTestCase extends StrutsTestCase {
 
     public String getConfigFilename() {
         return "xwork.xml";
@@ -74,7 +74,7 @@
 
         MockHttpSession session = new MockHttpSession();
 
-        WebWorkMockHttpServletRequest request = new WebWorkMockHttpServletRequest();
+        StrutsMockHttpServletRequest request = new StrutsMockHttpServletRequest();
         request.setSession(session);
         request.setupAddHeader("Content-Type", "dunno what this should be... just not multipart !");
         request.setParameterMap(getParameterMap());
@@ -82,7 +82,7 @@
         request.setupGetPathInfo(getServletPath());
         request.setupGetContentType("text/plain");
 
-        MockHttpServletResponse response = new WebWorkMockHttpServletResponse();
+        MockHttpServletResponse response = new StrutsMockHttpServletResponse();
         response.setupOutputStream(new MockServletOutputStream());
 
         Mock servletContextDMock = new Mock(ServletContext.class);

Modified: incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/DefautActionMapperTest.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/DefautActionMapperTest.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/DefautActionMapperTest.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/DefautActionMapperTest.java Tue Mar 28 16:52:39 2006
@@ -9,8 +9,8 @@
 package org.apache.struts.action2.dispatcher;
 
 import com.mockobjects.servlet.MockHttpServletRequest;
-import org.apache.struts.action2.WebWorkTestCase;
-import org.apache.struts.action2.WebWorkConstants;
+import org.apache.struts.action2.StrutsTestCase;
+import org.apache.struts.action2.StrutsConstants;
 import org.apache.struts.action2.config.Configuration;
 import org.apache.struts.action2.dispatcher.mapper.ActionMapping;
 import org.apache.struts.action2.dispatcher.mapper.DefaultActionMapper;
@@ -21,7 +21,7 @@
 /**
  * @author roughley
  */
-public class DefautActionMapperTest extends WebWorkTestCase {
+public class DefautActionMapperTest extends StrutsTestCase {
     private MockHttpServletRequest req;
 
     protected void setUp() throws Exception {
@@ -87,8 +87,8 @@
     }
 
     public void testGetMappingWithNoExtension() throws Exception {
-        Object old = Configuration.get(WebWorkConstants.WEBWORK_ACTION_EXTENSION);
-        Configuration.set(WebWorkConstants.WEBWORK_ACTION_EXTENSION, "");
+        Object old = Configuration.get(StrutsConstants.STRUTS_ACTION_EXTENSION);
+        Configuration.set(StrutsConstants.STRUTS_ACTION_EXTENSION, "");
         try {
             req.setupGetParameterMap(new HashMap());
             req.setupGetRequestURI("/my/namespace/actionName");
@@ -104,7 +104,7 @@
             assertNull(mapping.getMethod());
         }
         finally {
-            Configuration.set(WebWorkConstants.WEBWORK_ACTION_EXTENSION, old);
+            Configuration.set(StrutsConstants.STRUTS_ACTION_EXTENSION, old);
         }
     }
 }

Modified: incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/DispatcherUtilsTest.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/DispatcherUtilsTest.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/DispatcherUtilsTest.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/DispatcherUtilsTest.java Tue Mar 28 16:52:39 2006
@@ -31,7 +31,7 @@
 		
 		// some i18n messages from webwork-messages.properties
 		assertEquals(
-				LocalizedTextUtil.findDefaultText("webwork.messages.error.uploading", Locale.US, 
+				LocalizedTextUtil.findDefaultText("struts.messages.error.uploading", Locale.US, 
 						new Object[] { "some error messages" }), 
 				"Error uploading: some error messages");
 	}

Modified: incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/FilterDispatcherTest.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/FilterDispatcherTest.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/FilterDispatcherTest.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/FilterDispatcherTest.java Tue Mar 28 16:52:39 2006
@@ -12,7 +12,7 @@
 import org.springframework.mock.web.MockFilterConfig;
 import org.springframework.mock.web.MockServletContext;
 
-import org.apache.struts.action2.WebWorkConstants;
+import org.apache.struts.action2.StrutsConstants;
 import org.apache.struts.action2.config.Configuration;
 import org.apache.struts.action2.util.ObjectFactoryDestroyable;
 import org.apache.struts.action2.util.ObjectFactoryInitializable;
@@ -76,8 +76,8 @@
 		DispatcherUtils.setInstance(null);
 		
 		Map configMap = new HashMap();
-		configMap.put(WebWorkConstants.WEBWORK_OBJECTFACTORY, "org.apache.struts.action2.dispatcher.FilterDispatcherTest$InnerInitializableObjectFactory");
-		configMap.put(WebWorkConstants.WEBWORK_CONFIGURATION_XML_RELOAD, "false");
+		configMap.put(StrutsConstants.STRUTS_OBJECTFACTORY, "org.apache.struts.action2.dispatcher.FilterDispatcherTest$InnerInitializableObjectFactory");
+		configMap.put(StrutsConstants.STRUTS_CONFIGURATION_XML_RELOAD, "false");
 		Configuration.setConfiguration(new InnerConfiguration(configMap));
 		
 		MockServletContext servletContext = new MockServletContext();
@@ -96,8 +96,8 @@
 		DispatcherUtils.setInstance(null);
 		
 		Map configMap = new HashMap();
-		configMap.put(WebWorkConstants.WEBWORK_OBJECTFACTORY, "org.apache.struts.action2.dispatcher.FilterDispatcherTest$InnerInitailizableDestroyableObjectFactory");
-		configMap.put(WebWorkConstants.WEBWORK_CONFIGURATION_XML_RELOAD, "false");
+		configMap.put(StrutsConstants.STRUTS_OBJECTFACTORY, "org.apache.struts.action2.dispatcher.FilterDispatcherTest$InnerInitailizableDestroyableObjectFactory");
+		configMap.put(StrutsConstants.STRUTS_CONFIGURATION_XML_RELOAD, "false");
 		Configuration.setConfiguration(new InnerConfiguration(configMap));
 		
 		MockServletContext servletContext = new MockServletContext();

Modified: incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/PlainTextResultTest.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/PlainTextResultTest.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/PlainTextResultTest.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/PlainTextResultTest.java Tue Mar 28 16:52:39 2006
@@ -9,10 +9,10 @@
 import java.io.StringWriter;
 
 import com.opensymphony.util.ClassLoaderUtil;
-import org.apache.struts.action2.WebWorkStatics;
+import org.apache.struts.action2.StrutsStatics;
 import org.apache.struts.action2.views.jsp.AbstractUITagTest;
-import org.apache.struts.action2.views.jsp.WebWorkMockHttpServletResponse;
-import org.apache.struts.action2.views.jsp.WebWorkMockServletContext;
+import org.apache.struts.action2.views.jsp.StrutsMockHttpServletResponse;
+import org.apache.struts.action2.views.jsp.StrutsMockServletContext;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.mock.MockActionInvocation;
 import com.opensymphony.xwork.util.OgnlValueStack;
@@ -30,10 +30,10 @@
 	OgnlValueStack stack;
 	MockActionInvocation invocation;
 	ActionContext context;
-	WebWorkMockHttpServletResponse response;
+	StrutsMockHttpServletResponse response;
 	PrintWriter writer;
 	StringWriter stringWriter;
-	WebWorkMockServletContext servletContext;
+	StrutsMockServletContext servletContext;
 	
 
 	public void testPlainText() throws Exception {
@@ -114,13 +114,13 @@
 		
 		stringWriter = new StringWriter();
 		writer = new PrintWriter(stringWriter);
-		response = new WebWorkMockHttpServletResponse();
+		response = new StrutsMockHttpServletResponse();
 		response.setWriter(writer);
-		servletContext = new WebWorkMockServletContext();
+		servletContext = new StrutsMockServletContext();
 		stack = new OgnlValueStack();
 		context = new ActionContext(stack.getContext());
-		context.put(WebWorkStatics.HTTP_RESPONSE, response);
-		context.put(WebWorkStatics.SERVLET_CONTEXT, servletContext);
+		context.put(StrutsStatics.HTTP_RESPONSE, response);
+		context.put(StrutsStatics.SERVLET_CONTEXT, servletContext);
 		invocation = new MockActionInvocation();
 		invocation.setStack(stack);
 		invocation.setInvocationContext(context);

Modified: incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/ServletDispatcherResultTest.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/ServletDispatcherResultTest.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/ServletDispatcherResultTest.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/ServletDispatcherResultTest.java Tue Mar 28 16:52:39 2006
@@ -7,8 +7,8 @@
 import com.mockobjects.dynamic.C;
 import com.mockobjects.dynamic.Mock;
 import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.WebWorkStatics;
-import org.apache.struts.action2.WebWorkTestCase;
+import org.apache.struts.action2.StrutsStatics;
+import org.apache.struts.action2.StrutsTestCase;
 import com.opensymphony.xwork.ActionContext;
 import ognl.Ognl;
 
@@ -23,7 +23,7 @@
  * @author $author$
  * @version $Revision: 1.7 $
  */
-public class ServletDispatcherResultTest extends WebWorkTestCase implements WebWorkStatics {
+public class ServletDispatcherResultTest extends StrutsTestCase implements StrutsStatics {
 
     public void testInclude() {
         ServletDispatcherResult view = new ServletDispatcherResult();

Modified: incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/ServletDispatcherTest-xwork.xml
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/ServletDispatcherTest-xwork.xml?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/ServletDispatcherTest-xwork.xml (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/ServletDispatcherTest-xwork.xml Tue Mar 28 16:52:39 2006
@@ -1,9 +1,9 @@
 <!DOCTYPE xwork PUBLIC "-//OpenSymphony Group//XWork 1.1.1//EN" "http://www.opensymphony.com/xwork/xwork-1.1.1.dtd">
 
 <xwork>
-    <include file="webwork-default.xml"/>
+    <include file="struts-default.xml"/>
 
-    <package name="default" extends="webwork-default">
+    <package name="default" extends="struts-default">
 
         <interceptors>
             <interceptor name="assert" class="org.apache.struts.action2.dispatcher.ServletDispatchedTestAssertInterceptor"/>

Modified: incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/ServletDispatcherTest.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/ServletDispatcherTest.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/ServletDispatcherTest.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/ServletDispatcherTest.java Tue Mar 28 16:52:39 2006
@@ -28,7 +28,7 @@
         return "/Test.action";
     }
 
-//    public void testEncodingAndLocaleSetFromWebWorkProperties() throws IOException, ServletException {
+//    public void testEncodingAndLocaleSetFromStrutsProperties() throws IOException, ServletException {
 //        testServletDispatcher();
 //        assertEquals("ISO-8859-1",ServletDispatcher.getEncoding());
 //        assertEquals(Locale.GERMANY,ServletDispatcher.getLocale());

Modified: incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/ServletRedirectResultTest.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/ServletRedirectResultTest.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/ServletRedirectResultTest.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/ServletRedirectResultTest.java Tue Mar 28 16:52:39 2006
@@ -7,8 +7,8 @@
 import com.mockobjects.dynamic.C;
 import com.mockobjects.dynamic.Mock;
 import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.WebWorkStatics;
-import org.apache.struts.action2.WebWorkTestCase;
+import org.apache.struts.action2.StrutsStatics;
+import org.apache.struts.action2.StrutsTestCase;
 import com.opensymphony.xwork.ActionContext;
 import com.opensymphony.xwork.ActionInvocation;
 import com.opensymphony.xwork.mock.MockActionInvocation;
@@ -26,7 +26,7 @@
  * @author $author$
  * @version $Revision: 1.15 $
  */
-public class ServletRedirectResultTest extends WebWorkTestCase implements WebWorkStatics {
+public class ServletRedirectResultTest extends StrutsTestCase implements StrutsStatics {
 
     protected ServletRedirectResult view;
     private ActionContext oldContext;

Modified: incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/VelocityResultTest.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/VelocityResultTest.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/VelocityResultTest.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/VelocityResultTest.java Tue Mar 28 16:52:39 2006
@@ -100,7 +100,7 @@
         }
     }
 
-    class TestResult extends WebWorkResultSupport {
+    class TestResult extends StrutsResultSupport {
         public String finalLocation;
 
         protected void doExecute(String finalLocation, ActionInvocation invocation) throws Exception {

Modified: incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/mapper/DefaultActionMapperTest.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/mapper/DefaultActionMapperTest.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/mapper/DefaultActionMapperTest.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/mapper/DefaultActionMapperTest.java Tue Mar 28 16:52:39 2006
@@ -8,7 +8,7 @@
 import java.util.Map;
 
 import org.apache.struts.action2.dispatcher.ServletRedirectResult;
-import org.apache.struts.action2.views.jsp.WebWorkMockHttpServletRequest;
+import org.apache.struts.action2.views.jsp.StrutsMockHttpServletRequest;
 import com.opensymphony.xwork.Result;
 
 import junit.framework.TestCase;
@@ -63,7 +63,7 @@
 		Map parameterMap = new HashMap();
 		parameterMap.put(DefaultActionMapper.METHOD_PREFIX+"myMethod", "");
 		
-		WebWorkMockHttpServletRequest request = new WebWorkMockHttpServletRequest();
+		StrutsMockHttpServletRequest request = new StrutsMockHttpServletRequest();
 		request.setParameterMap(parameterMap);
 		request.setupGetServletPath("/someServletPath.action");
 		
@@ -77,7 +77,7 @@
 		Map parameterMap = new HashMap();
 		parameterMap.put(DefaultActionMapper.ACTION_PREFIX+"myAction", "");
 		
-		WebWorkMockHttpServletRequest request = new WebWorkMockHttpServletRequest();
+		StrutsMockHttpServletRequest request = new StrutsMockHttpServletRequest();
 		request.setParameterMap(parameterMap);
 		request.setupGetServletPath("/someServletPath.action");
 		
@@ -91,7 +91,7 @@
 		Map parameterMap = new HashMap();
 		parameterMap.put(DefaultActionMapper.REDIRECT_PREFIX+"www.google.com", "");
 		
-		WebWorkMockHttpServletRequest request = new WebWorkMockHttpServletRequest();
+		StrutsMockHttpServletRequest request = new StrutsMockHttpServletRequest();
 		request.setupGetServletPath("/someServletPath.action");
 		request.setParameterMap(parameterMap);
 		
@@ -109,7 +109,7 @@
 		Map parameterMap = new HashMap();
 		parameterMap.put(DefaultActionMapper.REDIRECT_ACTION_PREFIX+"myAction", "");
 		
-		WebWorkMockHttpServletRequest request = new WebWorkMockHttpServletRequest();
+		StrutsMockHttpServletRequest request = new StrutsMockHttpServletRequest();
 		request.setupGetServletPath("/someServletPath.action");
 		request.setParameterMap(parameterMap);
 		
@@ -130,7 +130,7 @@
 	// ==========================
 	public void testActionBangMethod() throws Exception {
 		
-		WebWorkMockHttpServletRequest request = new WebWorkMockHttpServletRequest();
+		StrutsMockHttpServletRequest request = new StrutsMockHttpServletRequest();
 		request.setupGetServletPath("/someName!someMethod.action");
 		
 		DefaultActionMapper defaultActionMapper = new DefaultActionMapper();

Modified: incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/mapper/RestfulActionMapperTest.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/mapper/RestfulActionMapperTest.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/mapper/RestfulActionMapperTest.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/dispatcher/mapper/RestfulActionMapperTest.java Tue Mar 28 16:52:39 2006
@@ -10,7 +10,7 @@
 import java.util.Collections;
 import java.util.HashMap;
 
-import org.apache.struts.action2.views.jsp.WebWorkMockHttpServletRequest;
+import org.apache.struts.action2.views.jsp.StrutsMockHttpServletRequest;
 
 /**
  * Unit test for {@link RestfulActionMapper}.
@@ -54,14 +54,14 @@
     }
 
     public void testGetMappingNoSlash() throws Exception {
-        WebWorkMockHttpServletRequest request = new WebWorkMockHttpServletRequest();
+        StrutsMockHttpServletRequest request = new StrutsMockHttpServletRequest();
         request.setupGetServletPath("noslash");
 
         assertNull(mapper.getMapping(request));
     }
 
     public void testGetMapping() throws Exception {
-        WebWorkMockHttpServletRequest request = new WebWorkMockHttpServletRequest();
+        StrutsMockHttpServletRequest request = new StrutsMockHttpServletRequest();
         request.setupGetServletPath("/myapp/view/12");
 
         ActionMapping am = mapper.getMapping(request);
@@ -71,7 +71,7 @@
     }
 
     public void testGetMapping2() throws Exception {
-        WebWorkMockHttpServletRequest request = new WebWorkMockHttpServletRequest();
+        StrutsMockHttpServletRequest request = new StrutsMockHttpServletRequest();
         request.setupGetServletPath("/myapp/12/region/europe");
 
         ActionMapping am = mapper.getMapping(request);
@@ -82,7 +82,7 @@
     }
 
     public void testGetMapping3() throws Exception {
-        WebWorkMockHttpServletRequest request = new WebWorkMockHttpServletRequest();
+        StrutsMockHttpServletRequest request = new StrutsMockHttpServletRequest();
         request.setupGetServletPath("/myapp/view/12/region/europe");
 
         ActionMapping am = mapper.getMapping(request);

Modified: incubator/webwork2/src/test/org/apache/struts/action2/interceptor/CreateSessionInterceptorTest.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/interceptor/CreateSessionInterceptorTest.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/interceptor/CreateSessionInterceptorTest.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/interceptor/CreateSessionInterceptorTest.java Tue Mar 28 16:52:39 2006
@@ -11,7 +11,7 @@
 import org.jmock.core.matcher.InvokeOnceMatcher;
 
 import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.WebWorkTestCase;
+import org.apache.struts.action2.StrutsTestCase;
 import com.opensymphony.xwork.mock.MockActionInvocation;
 
 /**
@@ -20,7 +20,7 @@
  * @author tm_jee
  * @version $Date: 2006/03/04 15:06:48 $ $Id: CreateSessionInterceptorTest.java,v 1.2 2006/03/04 15:06:48 rainerh Exp $
  */
-public class CreateSessionInterceptorTest extends WebWorkTestCase {
+public class CreateSessionInterceptorTest extends StrutsTestCase {
 
 	public void testCreateSession() throws Exception {
 		Mock httpServletRequestMock = new Mock(HttpServletRequest.class);

Modified: incubator/webwork2/src/test/org/apache/struts/action2/interceptor/ExecuteAndWaitInterceptorTest.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/interceptor/ExecuteAndWaitInterceptorTest.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/interceptor/ExecuteAndWaitInterceptorTest.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/interceptor/ExecuteAndWaitInterceptorTest.java Tue Mar 28 16:52:39 2006
@@ -6,9 +6,9 @@
 package org.apache.struts.action2.interceptor;
 
 import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.WebWorkTestCase;
-import org.apache.struts.action2.views.jsp.WebWorkMockHttpServletRequest;
-import org.apache.struts.action2.views.jsp.WebWorkMockHttpSession;
+import org.apache.struts.action2.StrutsTestCase;
+import org.apache.struts.action2.views.jsp.StrutsMockHttpServletRequest;
+import org.apache.struts.action2.views.jsp.StrutsMockHttpSession;
 import com.opensymphony.xwork.*;
 import com.opensymphony.xwork.mock.MockResult;
 import com.opensymphony.xwork.config.Configuration;
@@ -32,9 +32,9 @@
  *
  * @author Claus Ibsen
  */
-public class ExecuteAndWaitInterceptorTest extends WebWorkTestCase {
+public class ExecuteAndWaitInterceptorTest extends StrutsTestCase {
 
-    private WebWorkMockHttpServletRequest request;
+    private StrutsMockHttpServletRequest request;
     private HttpSession httpSession;
     private Map context;
     private Map params;
@@ -161,8 +161,8 @@
         context.put(ActionContext.SESSION, session);
         context.put(ActionContext.PARAMETERS, params);
 
-        request = new WebWorkMockHttpServletRequest();
-        httpSession = new WebWorkMockHttpSession();
+        request = new StrutsMockHttpServletRequest();
+        httpSession = new StrutsMockHttpSession();
         request.setSession(httpSession);
         request.setParameterMap(params);
         context.put(ServletActionContext.HTTP_REQUEST, request);

Modified: incubator/webwork2/src/test/org/apache/struts/action2/interceptor/FileUploadInterceptor.properties
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/interceptor/FileUploadInterceptor.properties?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/interceptor/FileUploadInterceptor.properties (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/interceptor/FileUploadInterceptor.properties Tue Mar 28 16:52:39 2006
@@ -1,3 +1,3 @@
 ### Unit test of FileUploadInterceptor
-webwork.messages.error.file.too.large=The file is to large to be uploaded {0} {1} {2} {3}
-webwork.messages.error.uploading=Error uploading: {0}
+struts.messages.error.file.too.large=The file is to large to be uploaded {0} {1} {2} {3}
+struts.messages.error.uploading=Error uploading: {0}

Modified: incubator/webwork2/src/test/org/apache/struts/action2/interceptor/FileUploadInterceptorTest.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/test/org/apache/struts/action2/interceptor/FileUploadInterceptorTest.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/test/org/apache/struts/action2/interceptor/FileUploadInterceptorTest.java (original)
+++ incubator/webwork2/src/test/org/apache/struts/action2/interceptor/FileUploadInterceptorTest.java Tue Mar 28 16:52:39 2006
@@ -6,7 +6,7 @@
 
 import com.opensymphony.util.ClassLoaderUtil;
 import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.WebWorkTestCase;
+import org.apache.struts.action2.StrutsTestCase;
 import org.apache.struts.action2.dispatcher.multipart.MultiPartRequestWrapper;
 import com.opensymphony.xwork.*;
 import com.opensymphony.xwork.mock.MockActionInvocation;
@@ -30,7 +30,7 @@
  * @author Claus Ibsen
  * @version $Date: 2006/03/17 22:46:24 $ $Id: FileUploadInterceptorTest.java,v 1.8 2006/03/17 22:46:24 mrdon Exp $
  */
-public class FileUploadInterceptorTest extends WebWorkTestCase {
+public class FileUploadInterceptorTest extends StrutsTestCase {
 
     private FileUploadInterceptor interceptor;
 



---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe@struts.apache.org
For additional commands, e-mail: dev-help@struts.apache.org
--- incubator/webwork2/src/java/org/apache/struts/action2/util/VelocityWebWorkUtil.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/util/VelocityStrutsUtil.java Tue Mar 28 16:52:39 2006
@@ -18,15 +18,15 @@
 
 
 /**
  * WebWork velocity related util.
  *
  * @author CameronBraid
  */
-public class VelocityWebWorkUtil extends WebWorkUtil {
+public class VelocityStrutsUtil extends StrutsUtil {
 
     private Context ctx;
 
-    public VelocityWebWorkUtil(Context ctx, OgnlValueStack stack, HttpServletRequest request, HttpServletResponse response) {
+    public VelocityStrutsUtil(Context ctx, OgnlValueStack stack, HttpServletRequest request, HttpServletResponse response) {
         super(stack, request, response);
         this.ctx = ctx;
     }
@@ -18,15 +18,15 @@
 
 /**
- * WebWork velocity related util.
+ * Struts velocity related util.
  *
  * @author CameronBraid

Modified: incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/FreemarkerManager.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/FreemarkerManager.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/WebWorkBeanWrapper.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/StrutsBeanWrapper.java Tue Mar 28 16:52:39 2006
@@ -12,21 +12,21 @@
 /**
  * <!-- START SNIPPET: javadoc -->
  *
  * The WebWorkBeanWrapper extends the default FreeMarker BeansWrapper and provides almost no change in functionality,
  * <b>except</b> for how it handles maps. Normally, FreeMarker has two modes of operation: either support for friendly
  * map built-ins (?keys, ?values, etc) but only support for String keys; OR no special built-in support (ie: ?keys
- * returns the methods on the map instead of the keys) but support for String and non-String keys alike. WebWork
+ * returns the methods on the map instead of the keys) but support for String and non-String keys alike. Struts
  * provides an alternative implementation that gives us the best of both worlds.
  *
  * <p/> It is possible that this special behavior may be confusing or can cause problems. Therefore, you can set the
- * <b>webwork.freemarker.wrapper.altMap</b> property in webwork.properties to false, allowing the normal BeansWrapper
+ * <b>struts.freemarker.wrapper.altMap</b> property in struts.properties to false, allowing the normal BeansWrapper
  * logic to take place instead.
  *
  * <!-- END SNIPPET: javadoc -->
  */
-public class WebWorkBeanWrapper extends BeansWrapper {
+public class StrutsBeanWrapper extends BeansWrapper {
     private static final boolean altMapWrapper
-            = "true".equals(org.apache.struts.action2.config.Configuration.get("webwork.freemarker.wrapper.altMap"));
+            = "true".equals(org.apache.struts.action2.config.Configuration.get("struts.freemarker.wrapper.altMap"));
 
     public TemplateModel wrap(Object object) throws TemplateModelException {
         if (object instanceof TemplateBooleanModel) {
@@ -12,21 +12,21 @@
  * <!-- START SNIPPET: javadoc -->
  *
- * The WebWorkBeanWrapper extends the default FreeMarker BeansWrapper and provides almost no change in functionality,
+ * The StrutsBeanWrapper extends the default FreeMarker BeansWrapper and provides almost no change in functionality,
  * <b>except</b> for how it handles maps. Normally, FreeMarker has two modes of operation: either support for friendly
  * map built-ins (?keys, ?values, etc) but only support for String keys; OR no special built-in support (ie: ?keys

Copied: incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/StrutsClassTemplateLoader.java (from r389620, incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/WebWorkClassTemplateLoader.java)
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/StrutsClassTemplateLoader.java?p2=incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/StrutsClassTemplateLoader.java&p1=incubator/webwork2/src/java/org/apache/struts/action2/views/freemarker/WebWorkClassTemplateLoader.java&r1=389620&r2=389643&rev=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/jasperreports/JasperReportsResult.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/jasperreports/JasperReportsResult.java Tue Mar 28 16:52:39 2006
@@ -30,7 +30,7 @@
 
 import com.opensymphony.util.TextUtils;
 import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.dispatcher.WebWorkResultSupport;
+import org.apache.struts.action2.dispatcher.StrutsResultSupport;
 import com.opensymphony.xwork.ActionInvocation;
 import com.opensymphony.xwork.util.OgnlValueStack;
 
@@ -76,7 +76,7 @@
  * </ul>
  *
  * <p>
  * This result follows the same rules from {@link WebWorkResultSupport}.
  * Specifically, all parameters will be parsed if the "parse" parameter is not 
  * set to false.
  * </p>
@@ -102,7 +102,7 @@
  * @author Patrick Lightbody
  * @author Rainer Hermanns
  */
-public class JasperReportsResult extends WebWorkResultSupport implements JasperReportConstants {
+public class JasperReportsResult extends StrutsResultSupport implements JasperReportConstants {
     private final static Log LOG = LogFactory.getLog(JasperReportsResult.class);
 
 
@@ -76,7 +76,7 @@
  *
  * <p>
- * This result follows the same rules from {@link WebWorkResultSupport}.
+ * This result follows the same rules from {@link StrutsResultSupport}.
  * Specifically, all parameters will be parsed if the "parse" parameter is not 
  * set to false.

Modified: incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/ComponentTagSupport.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/ComponentTagSupport.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/WebWorkBodyTagSupport.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/StrutsBodyTagSupport.java Tue Mar 28 16:52:39 2006
@@ -13,14 +13,14 @@
 
 
 /**
  * Contains common functonalities for WebWork JSP Tags.
  * 
  * @author plightbo
  * @author tm_jee
  * Date: Oct 17, 2003
  * Time: 7:09:15 AM
  */
-public class WebWorkBodyTagSupport extends BodyTagSupport {
+public class StrutsBodyTagSupport extends BodyTagSupport {
 
     private static final long serialVersionUID = -1201668454354226175L;
 
@@ -13,14 +13,14 @@
 
 /**
- * Contains common functonalities for WebWork JSP Tags.
+ * Contains common functonalities for Struts JSP Tags.
  * 
  * @author plightbo

Modified: incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/TagUtils.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/jsp/TagUtils.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================
--- incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/VelocityManager.java (original)
+++ incubator/webwork2/src/java/org/apache/struts/action2/views/velocity/VelocityManager.java Tue Mar 28 16:52:39 2006
@@ -5,9 +5,9 @@
 package org.apache.struts.action2.views.velocity;
 
 import org.apache.struts.action2.ServletActionContext;
-import org.apache.struts.action2.WebWorkConstants;
+import org.apache.struts.action2.StrutsConstants;
 import org.apache.struts.action2.config.Configuration;
-import org.apache.struts.action2.util.VelocityWebWorkUtil;
+import org.apache.struts.action2.util.VelocityStrutsUtil;
 import org.apache.struts.action2.views.jsp.ui.OgnlTool;
 import org.apache.struts.action2.views.util.ContextUtil;
 import org.apache.struts.action2.views.velocity.components.*;
@@ -41,7 +41,7 @@
 public class VelocityManager {
     private static final Log log = LogFactory.getLog(VelocityManager.class);
     private static VelocityManager instance;
-    public static final String WEBWORK = "webwork";
+    public static final String STRUTS = "webwork";
 
     /**
      * the parent JSP tag
@@ -80,8 +80,8 @@
         if (instance == null) {
             String classname = VelocityManager.class.getName();
 
-            if (Configuration.isSet(WebWorkConstants.WEBWORK_VELOCITY_MANAGER_CLASSNAME)) {
-                classname = Configuration.getString(WebWorkConstants.WEBWORK_VELOCITY_MANAGER_CLASSNAME).trim();
+            if (Configuration.isSet(StrutsConstants.STRUTS_VELOCITY_MANAGER_CLASSNAME)) {
+                classname = Configuration.getString(StrutsConstants.STRUTS_VELOCITY_MANAGER_CLASSNAME).trim();
             }
 
             if (!classname.equals(VelocityManager.class.getName())) {
@@ -118,21 +118,21 @@
      * <li><strong>res</strong> - the current HttpServletResponse</li>
      * <li><strong>stack</strong> - the current {@link OgnlValueStack}</li>
      * <li><strong>ognl</strong> - an {@link OgnlTool}</li>
-     * <li><strong>webwork</strong> - an instance of {@link org.apache.struts.action2.util.WebWorkUtil}</li>
-     * <li><strong>action</strong> - the current WebWork action</li>
+     * <li><strong>webwork</strong> - an instance of {@link org.apache.struts.action2.util.StrutsUtil}</li>
+     * <li><strong>action</strong> - the current Struts action</li>
      * </ul>
      *
-     * @return a new WebWorkVelocityContext
+     * @return a new StrutsVelocityContext
      */
     public Context createContext(OgnlValueStack stack, HttpServletRequest req, HttpServletResponse res) {
         VelocityContext[] chainedContexts = prepareChainedContexts(req, res, stack.getContext());
-        WebWorkVelocityContext context = new WebWorkVelocityContext(chainedContexts, stack);
+        StrutsVelocityContext context = new StrutsVelocityContext(chainedContexts, stack);
         Map standardMap = ContextUtil.getStandardContext(stack, req, res);
         for (Iterator iterator = standardMap.entrySet().iterator(); iterator.hasNext();) {
             Map.Entry entry = (Map.Entry) iterator.next();
             context.put((String) entry.getKey(), entry.getValue());
         }
-        context.put(WEBWORK, new VelocityWebWorkUtil(context, stack, req, res));
+        context.put(STRUTS, new VelocityStrutsUtil(context, stack, req, res));
 
 
         ServletContext ctx = null;
@@ -208,7 +208,7 @@
      * </ul>
      *
      * @param context the current ServletContext.  may <b>not</b> be null
-     * @return the optional properties if webwork.velocity.configfile was specified, an empty Properties file otherwise
+     * @return the optional properties if struts.velocity.configfile was specified, an empty Properties file otherwise
      */
     public Properties loadConfiguration(ServletContext context) {
         if (context == null) {
@@ -235,8 +235,8 @@
          */
         String configfile;
 
-        if (Configuration.isSet(WebWorkConstants.WEBWORK_VELOCITY_CONFIGFILE)) {
-            configfile = Configuration.getString(WebWorkConstants.WEBWORK_VELOCITY_CONFIGFILE);
+        if (Configuration.isSet(StrutsConstants.STRUTS_VELOCITY_CONFIGFILE)) {
+            configfile = Configuration.getString(StrutsConstants.STRUTS_VELOCITY_CONFIGFILE);
         } else {
             configfile = "velocity.properties";
         }
@@ -342,8 +342,8 @@
         initChainedContexts();
 
 
-        if (Configuration.isSet(WebWorkConstants.WEBWORK_VELOCITY_TOOLBOXLOCATION)) {
-            toolBoxLocation = Configuration.get(WebWorkConstants.WEBWORK_VELOCITY_TOOLBOXLOCATION).toString();
+        if (Configuration.isSet(StrutsConstants.STRUTS_VELOCITY_TOOLBOXLOCATION)) {
+            toolBoxLocation = Configuration.get(StrutsConstants.STRUTS_VELOCITY_TOOLBOXLOCATION).toString();
         }
 
     }
@@ -364,16 +364,16 @@
 
 
     /**
      * allow users to specify via the webwork.properties file a set of additional VelocityContexts to chain to the
      * the WebWorkVelocityContext.  The intent is to allow these contexts to store helper objects that the ui
      * developer may want access to.  Examples of reasonable VelocityContexts would be an IoCVelocityContext, a
      * SpringReferenceVelocityContext, and a ToolboxVelocityContext
      */
     protected void initChainedContexts() {
 
-        if (Configuration.isSet(WebWorkConstants.WEBWORK_VELOCITY_CONTEXTS)) {
+        if (Configuration.isSet(StrutsConstants.STRUTS_VELOCITY_CONTEXTS)) {
             // we expect contexts to be a comma separated list of classnames
-            String contexts = Configuration.get(WebWorkConstants.WEBWORK_VELOCITY_CONTEXTS).toString();
+            String contexts = Configuration.get(StrutsConstants.STRUTS_VELOCITY_CONTEXTS).toString();
             StringTokenizer st = new StringTokenizer(contexts, ",");
             List contextList = new ArrayList();
 
@@ -403,11 +403,11 @@
      *  resource.loader = file, class
      *  file.resource.loader.path = real path of webapp
      *  class.resource.loader.description = Velocity Classpath Resource Loader
-     *  class.resource.loader.class = org.apache.struts.action2.views.velocity.WebWorkResourceLoader
+     *  class.resource.loader.class = org.apache.struts.action2.views.velocity.StrutsResourceLoader
      * </pre>
      * <p/>
-     * this default configuration can be overridden by specifying a webwork.velocity.configfile property in the
-     * webwork.properties file.  the specified config file will be searched for in the following order:
+     * this default configuration can be overridden by specifying a struts.velocity.configfile property in the
+     * struts.properties file.  the specified config file will be searched for in the following order:
      * </p>
      * <ul>
      * <li>relative to the servlet context path</li>
@@ -445,11 +445,11 @@
     }
 
     /**
-     * once we've loaded up the user defined configurations, we will want to apply WebWork specification configurations.
+     * once we've loaded up the user defined configurations, we will want to apply Struts specification configurations.
      * <ul>
      * <li>if Velocity.RESOURCE_LOADER has not been defined, then we will use the defaults which is a joined file,
      * class loader for unpackaed wars and a straight class loader otherwise</li>
-     * <li>we need to define the various WebWork custom user directives such as #param, #tag, and #bodytag</li>
+     * <li>we need to define the various Struts custom user directives such as #param, #tag, and #bodytag</li>
      * </ul>
      *
      * @param context
@@ -493,13 +493,13 @@
         }
 
         /**
-         * Refactored the Velocity templates for the WebWork taglib into the classpath from the web path.  This will
-         * enable WebWork projects to have access to the templates by simply including the WebWork jar file.
+         * Refactored the Velocity templates for the Struts taglib into the classpath from the web path.  This will
+         * enable Struts projects to have access to the templates by simply including the Struts jar file.
          * Unfortunately, there does not appear to be a macro for the class loader keywords
          * Matt Ho - Mon Mar 17 00:21:46 PST 2003
          */
         p.setProperty("wwclass.resource.loader.description", "Velocity Classpath Resource Loader");
-        p.setProperty("wwclass.resource.loader.class", "org.apache.struts.action2.views.velocity.WebWorkResourceLoader");
+        p.setProperty("wwclass.resource.loader.class", "org.apache.struts.action2.views.velocity.StrutsResourceLoader");
         p.setProperty("wwclass.resource.loader.modificationCheckInterval", "2");
         p.setProperty("wwclass.resource.loader.cache", "true");
 
@@ -364,16 +364,16 @@
 
     /**
-     * allow users to specify via the webwork.properties file a set of additional VelocityContexts to chain to the
-     * the WebWorkVelocityContext.  The intent is to allow these contexts to store helper objects that the ui
+     * allow users to specify via the struts.properties file a set of additional VelocityContexts to chain to the
+     * the StrutsVelocityContext.  The intent is to allow these contexts to store helper objects that the ui
      * developer may want access to.  Examples of reasonable VelocityContexts would be an IoCVelocityContext, a
      * SpringReferenceVelocityContext, and a ToolboxVelocityContext

Modified: incubator/webwork2/src/java/org/apache/struts/action2/views/xslt/BeanAdapter.java
URL: http://svn.apache.org/viewcvs/incubator/webwork2/src/java/org/apache/struts/action2/views/xslt/BeanAdapter.java?rev=389643&r1=389642&r2=389643&view=diff
==============================================================================